@@ -12,11 +12,11 @@ def get_url(
         "operasoftware", "operachromiumdriver", version, prefix="v."
     )
     for u in urls:
-        if "{}{}".format(_os, _os_bit) in u:
+        if f"{_os}{_os_bit}" in u:
             ver = re.search(r"v\.(\d{1,2}\.\d{1,2})", u)
             if ver is not None:
                 return "operadriver.*/operadriver", u, str(ver.group(1))
-    raise ValueError("Unable to get url")
+    raise ValueError(f"Unable to locate OperaDriver version! [{version}]")
 
 
 if __name__ == "__main__":
